@@ -32,7 +32,8 @@ let unsafe_get_uint8 t off = Char.code (String.unsafe_get t off)
 
 let unsafe_set_uint8 t off v = Bytes.unsafe_set t off (Char.chr v)
 
-let unsafe_set_uint16 = Unsafe.unsafe_set_uint16
+external unsafe_set_uint16 : bytes -> int -> int -> unit = "%caml_bytes_set16u"
+  [@@noalloc]
 
 external unsafe_get_uint16 : string -> int -> int = "%caml_string_get16u"
   [@@noalloc]
